//  NLPUtils Project
//  Morphological Parser
//  MorphParserTest.cs
//
//  Author: Cody Boisclair
//  Version: 1.0b1

using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;

namespace NLPUtils
{
    class MorphParserTest
    {
        static void Main(string[] args)
        {
            if (args.Length < 1  || (args[0] == "-l" && args.Length < 2) ||
                (args[0] == "-s" && args.Length < 2))
            {
                string assemName = Assembly.GetExecutingAssembly().GetName().Name;
                Console.WriteLine(assemName + " - Using MorphParser version: " + MorphParser.Version);
                Console.WriteLine();
                Console.WriteLine("Usage:");
                Console.WriteLine("  " + assemName + " [word to parse]");
                Console.WriteLine("To parse an entire sentence:");
                Console.WriteLine("  " + assemName + " -s [sentence to parse]");
                Environment.Exit(1);
            }

            MorphParser.IrregularsFilePath = "IrregularForms.xml";

            if (args[0] == "-s")
            {
                String str = "";
                for (int i = 1; i < args.Length; i++) {
                    str += args[i] + " ";
                }
                str = str.Substring(0, str.Length-1);

                List<List<List<Morph>>> result = MorphParser.TokenizeAndParse(str);

                foreach (List<List<Morph>> thisParses in result)
                {
                    DisplayParses(thisParses);
                }

                Environment.Exit(0);
            }

            string word = args[0];

            List<List<Morph>> parses = MorphParser.ParseWord(word);

            DisplayParses(parses);
        }

        /// <summary>
        /// Displays the result of a morphological parse in human-readable form, e.g.:
        /// { stem +feat +feat | stem +feat +feat | ... }
        /// </summary>
        /// <param name="parses">The list of possible parses to display.</param>
        static void DisplayParses(List<List<Morph>> parses)
        {
            Console.Write("{ ");
            foreach (List<Morph> parse in parses)
            {
                if (parse != parses[0])
                    Console.Write(" | ");
                foreach (Morph morph in parse)
                {
                    if (morph != parse[0])
                        Console.Write(" ");
                    if (morph.Type == MorphType.Stem)
                        Console.Write("(" + morph.Category + ") ");
                    Console.Write(morph);
                }
            }
            Console.WriteLine(" }");
        }
    }
}
